# OpenAIAuth
OpenAI Authentication Library for ChatGPT

# Credits
Thank you to:
- [rawandahmad698](https://github.com/rawandahmad698)
for the reverse engineering of the protocol
- [FlorianREGAZ](https://github.com/FlorianREGAZ)
for the TLS Client
